/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This file was generated.
 *  with google-apis-code-generator 1.4.0 (build: 2013-06-26 16:27:34 UTC)
 *  on 2013-06-26 at 18:56:40 UTC 
 */

package com.google.api.services.groupssettings;

import com.google.api.client.googleapis.GoogleUtils;
import com.google.api.client.googleapis.services.AbstractGoogleClientRequest;
import com.google.api.client.googleapis.services.GoogleClientRequestInitializer;
import com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient;
import com.google.api.client.http.HttpRequestInitializer;
import com.google.api.client.http.HttpTransport;
import com.google.api.client.json.JsonFactory;
import com.google.api.client.json.JsonObjectParser;
import com.google.common.base.Preconditions;

/**
 * Service definition for Groupssettings (v1).
 *
 * <p>
 * Lets you manage permission levels and related settings of a group.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/google-apps/groups-settings/get_started" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link GroupssettingsRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * <p>
 * Upgrade warning: this class now extends {@link AbstractGoogleJsonClient}, whereas in prior
 * version 1.8 it extended {@link com.google.api.client.googleapis.services.GoogleClient}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class Groupssettings extends AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    Preconditions.checkState(GoogleUtils.VERSION.equals("1.13.2-beta"),
        "You are currently running with version %s of google-api-client. " +
        "You need version 1.13.2-beta of google-api-client to run version " +
        "1.13.2-beta of the Groups Settings API library.", GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "groups/v1/groups/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   * @deprecated (scheduled to be removed in 1.13)
   */
  @Deprecated
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport
   * @param jsonFactory JSON factory
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public Groupssettings(HttpTransport transport, JsonFactory jsonFactory,
      HttpRequestInitializer httpRequestInitializer) {
    super(transport,
        jsonFactory,
        DEFAULT_ROOT_URL,
        DEFAULT_SERVICE_PATH,
        httpRequestInitializer,
        false);
  }

  /**
   * @param transport HTTP transport
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @param rootUrl root URL of the service
   * @param servicePath service path
   * @param jsonObjectParser JSON object parser
   * @param googleClientRequestInitializer Google request initializer or {@code null} for none
   * @param applicationName application name to be sent in the User-Agent header of requests or
   *        {@code null} for none
   * @param suppressPatternChecks whether discovery pattern checks should be suppressed on required
   *        parameters
   */
  Groupssettings(HttpTransport transport,
      HttpRequestInitializer httpRequestInitializer,
      String rootUrl,
      String servicePath,
      JsonObjectParser jsonObjectParser,
      GoogleClientRequestInitializer googleClientRequestInitializer,
      String applicationName,
      boolean suppressPatternChecks) {
    super(transport,
        httpRequestInitializer,
        rootUrl,
        servicePath,
        jsonObjectParser,
        googleClientRequestInitializer,
        applicationName,
        suppressPatternChecks);
  }

  @Override
  protected void initialize(AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the Groups collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Groupssettings groupssettings = new Groupssettings(...);}
   *   {@code Groupssettings.Groups.List request = groupssettings.groups().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Groups groups() {
    return new Groups();
  }

  /**
   * The "groups" collection of methods.
   */
  public class Groups {

    /**
     * Gets one resource by id.
     *
     * Create a request for the method "groups.get".
     *
     * This request holds the parameters needed by the the groupssettings server.  After setting any
     * optional parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param groupUniqueId The resource ID
     * @return the request
     */
    public Get get(String groupUniqueId) throws java.io.IOException {
      Get result = new Get(groupUniqueId);
      initialize(result);
      return result;
    }

    public class Get extends GroupssettingsRequest<com.google.api.services.groupssettings.model.Groups> {

      private static final String REST_PATH = "{groupUniqueId}";

      /**
       * Gets one resource by id.
       *
       * Create a request for the method "groups.get".
       *
       * This request holds the parameters needed by the the groupssettings server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param groupUniqueId The resource ID
       * @since 1.13
       */
      protected Get(String groupUniqueId) {
        super(Groupssettings.this, "GET", REST_PATH, null, com.google.api.services.groupssettings.model.Groups.class);
        this.groupUniqueId = Preconditions.checkNotNull(groupUniqueId, "Required parameter groupUniqueId must be specified.");
        set("alt", "json");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** The resource ID */
      @com.google.api.client.util.Key
      private String groupUniqueId;

      /** The resource ID
       */
      public String getGroupUniqueId() {
        return groupUniqueId;
      }

      /** The resource ID */
      public Get setGroupUniqueId(String groupUniqueId) {
        this.groupUniqueId = groupUniqueId;
        return this;
      }

    }
    /**
     * Updates an existing resource. This method supports patch semantics.
     *
     * Create a request for the method "groups.patch".
     *
     * This request holds the parameters needed by the the groupssettings server.  After setting any
     * optional parameters, call the {@link Patch#execute()} method to invoke the remote operation.
     *
     * @param groupUniqueId The resource ID
     * @param content the {@link com.google.api.services.groupssettings.model.Groups}
     * @return the request
     */
    public Patch patch(String groupUniqueId, com.google.api.services.groupssettings.model.Groups content) throws java.io.IOException {
      Patch result = new Patch(groupUniqueId, content);
      initialize(result);
      return result;
    }

    public class Patch extends GroupssettingsRequest<com.google.api.services.groupssettings.model.Groups> {

      private static final String REST_PATH = "{groupUniqueId}";

      /**
       * Updates an existing resource. This method supports patch semantics.
       *
       * Create a request for the method "groups.patch".
       *
       * This request holds the parameters needed by the the groupssettings server.  After setting any
       * optional parameters, call the {@link Patch#execute()} method to invoke the remote operation.
       * <p> {@link Patch#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param groupUniqueId The resource ID
       * @param content the {@link com.google.api.services.groupssettings.model.Groups}
       * @since 1.13
       */
      protected Patch(String groupUniqueId, com.google.api.services.groupssettings.model.Groups content) {
        super(Groupssettings.this, "PATCH", REST_PATH, content, com.google.api.services.groupssettings.model.Groups.class);
        this.groupUniqueId = Preconditions.checkNotNull(groupUniqueId, "Required parameter groupUniqueId must be specified.");
        set("alt", "json");
      }

      @Override
      public Patch setAlt(String alt) {
        return (Patch) super.setAlt(alt);
      }

      @Override
      public Patch setFields(String fields) {
        return (Patch) super.setFields(fields);
      }

      @Override
      public Patch setKey(String key) {
        return (Patch) super.setKey(key);
      }

      @Override
      public Patch setOauthToken(String oauthToken) {
        return (Patch) super.setOauthToken(oauthToken);
      }

      @Override
      public Patch setPrettyPrint(Boolean prettyPrint) {
        return (Patch) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Patch setQuotaUser(String quotaUser) {
        return (Patch) super.setQuotaUser(quotaUser);
      }

      @Override
      public Patch setUserIp(String userIp) {
        return (Patch) super.setUserIp(userIp);
      }

      /** The resource ID */
      @com.google.api.client.util.Key
      private String groupUniqueId;

      /** The resource ID
       */
      public String getGroupUniqueId() {
        return groupUniqueId;
      }

      /** The resource ID */
      public Patch setGroupUniqueId(String groupUniqueId) {
        this.groupUniqueId = groupUniqueId;
        return this;
      }

    }
    /**
     * Updates an existing resource.
     *
     * Create a request for the method "groups.update".
     *
     * This request holds the parameters needed by the the groupssettings server.  After setting any
     * optional parameters, call the {@link Update#execute()} method to invoke the remote operation.
     *
     * @param groupUniqueId The resource ID
     * @param content the {@link com.google.api.services.groupssettings.model.Groups}
     * @return the request
     */
    public Update update(String groupUniqueId, com.google.api.services.groupssettings.model.Groups content) throws java.io.IOException {
      Update result = new Update(groupUniqueId, content);
      initialize(result);
      return result;
    }

    public class Update extends GroupssettingsRequest<com.google.api.services.groupssettings.model.Groups> {

      private static final String REST_PATH = "{groupUniqueId}";

      /**
       * Updates an existing resource.
       *
       * Create a request for the method "groups.update".
       *
       * This request holds the parameters needed by the the groupssettings server.  After setting any
       * optional parameters, call the {@link Update#execute()} method to invoke the remote operation.
       * <p> {@link Update#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param groupUniqueId The resource ID
       * @param content the {@link com.google.api.services.groupssettings.model.Groups}
       * @since 1.13
       */
      protected Update(String groupUniqueId, com.google.api.services.groupssettings.model.Groups content) {
        super(Groupssettings.this, "PUT", REST_PATH, content, com.google.api.services.groupssettings.model.Groups.class);
        this.groupUniqueId = Preconditions.checkNotNull(groupUniqueId, "Required parameter groupUniqueId must be specified.");
        set("alt", "json");
      }

      @Override
      public Update setAlt(String alt) {
        return (Update) super.setAlt(alt);
      }

      @Override
      public Update setFields(String fields) {
        return (Update) super.setFields(fields);
      }

      @Override
      public Update setKey(String key) {
        return (Update) super.setKey(key);
      }

      @Override
      public Update setOauthToken(String oauthToken) {
        return (Update) super.setOauthToken(oauthToken);
      }

      @Override
      public Update setPrettyPrint(Boolean prettyPrint) {
        return (Update) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Update setQuotaUser(String quotaUser) {
        return (Update) super.setQuotaUser(quotaUser);
      }

      @Override
      public Update setUserIp(String userIp) {
        return (Update) super.setUserIp(userIp);
      }

      /** The resource ID */
      @com.google.api.client.util.Key
      private String groupUniqueId;

      /** The resource ID
       */
      public String getGroupUniqueId() {
        return groupUniqueId;
      }

      /** The resource ID */
      public Update setGroupUniqueId(String groupUniqueId) {
        this.groupUniqueId = groupUniqueId;
        return this;
      }

    }

  }

  /**
   * Builder for {@link Groupssettings}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport
     * @param jsonFactory JSON factory
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(HttpTransport transport, JsonFactory jsonFactory,
        HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
    }

    /** Builds a new instance of {@link Groupssettings}. */
    @Override
    public Groupssettings build() {
      return new Groupssettings(getTransport(),
          getHttpRequestInitializer(),
          getRootUrl(),
          getServicePath(),
          getObjectParser(),
          getGoogleClientRequestInitializer(),
          getApplicationName(),
          getSuppressPatternChecks());
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    /**
     * Set the {@link GroupssettingsRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setGroupssettingsRequestInitializer(
        GroupssettingsRequestInitializer groupssettingsRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(groupssettingsRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
